@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2013-2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,9 +24,7 @@
 
 #include <QDialog>
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class SelectSpecialCharDialogPrivate;
 
 class KPIMTEXTEDIT_EXPORT SelectSpecialCharDialog : public QDialog
@@ -36,7 +34,7 @@ public:
     explicit SelectSpecialCharDialog(QWidget *parent);
     ~SelectSpecialCharDialog();
 
-    void setCurrentChar(const QChar &c);
+    void setCurrentChar(QChar c);
     QChar currentChar() const;
 
     void setOkButtonText(const QString &text);
@@ -49,14 +47,12 @@ public:
     void autoInsertChar();
 
 Q_SIGNALS:
-    void charSelected(const QChar &);
+    void charSelected(QChar);
 
 private:
     SelectSpecialCharDialogPrivate *const d;
     friend class SelectSpecialCharDialogPrivate;
-    Q_PRIVATE_SLOT(d, void _k_slotInsertChar())
 };
-
 }
 
 #endif // KPIMTEXTEDIT_SELECTSPECIAL_CHAR_H
